==> mx-1.0.4.tar.bz2: mx-1.0.4/mx/mx-enum-types.h <==

/* Generated data (by glib-mkenums) */

#if !defined(MX_H_INSIDE) && !defined(MX_COMPILATION)
#error "Only <mx/mx.h> can be included directly.h"
#endif

#ifndef __MX_ENUM_TYPES_H__
#define __MX_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "../mx/mx-application.h" */
GType mx_application_flags_get_type (void) G_GNUC_CONST;
#define MX_TYPE_APPLICATION_FLAGS (mx_application_flags_get_type())

/* enumerations from "../mx/mx-draggable.h" */
GType mx_drag_axis_get_type (void) G_GNUC_CONST;
#define MX_TYPE_DRAG_AXIS (mx_drag_axis_get_type())

/* enumerations from "../mx/mx-focusable.h" */
GType mx_focus_direction_get_type (void) G_GNUC_CONST;
#define MX_TYPE_FOCUS_DIRECTION (mx_focus_direction_get_type())

GType mx_focus_hint_get_type (void) G_GNUC_CONST;
#define MX_TYPE_FOCUS_HINT (mx_focus_hint_get_type())

/* enumerations from "../mx/mx-stylable.h" */
GType mx_style_changed_flags_get_type (void) G_GNUC_CONST;
#define MX_TYPE_STYLE_CHANGED_FLAGS (mx_style_changed_flags_get_type())

/* enumerations from "../mx/mx-style.h" */
GType mx_style_error_get_type (void) G_GNUC_CONST;
#define MX_TYPE_STYLE_ERROR (mx_style_error_get_type())

/* enumerations from "../mx/mx-types.h" */
GType mx_align_get_type (void) G_GNUC_CONST;
#define MX_TYPE_ALIGN (mx_align_get_type())

GType mx_font_weight_get_type (void) G_GNUC_CONST;
#define MX_TYPE_FONT_WEIGHT (mx_font_weight_get_type())

GType mx_scroll_policy_get_type (void) G_GNUC_CONST;
#define MX_TYPE_SCROLL_POLICY (mx_scroll_policy_get_type())

GType mx_orientation_get_type (void) G_GNUC_CONST;
#define MX_TYPE_ORIENTATION (mx_orientation_get_type())

/* enumerations from "../mx/mx-widget.h" */
GType mx_long_press_action_get_type (void) G_GNUC_CONST;
#define MX_TYPE_LONG_PRESS_ACTION (mx_long_press_action_get_type())

G_END_DECLS

#endif /* !__MX_ENUM_TYPES_H__ */

/* Generated data ends here */

==> mx_1.2.0.orig.tar.bz2: mx-1.2.0/mx/mx-enum-types.h <==

/* Generated data (by glib-mkenums) */

#if !defined(MX_H_INSIDE) && !defined(MX_COMPILATION)
#error "Only <mx/mx.h> can be included directly.h"
#endif

#ifndef __MX_ENUM_TYPES_H__
#define __MX_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "../mx/mx-actor-manager.h" */
GType mx_actor_manager_error_get_type (void) G_GNUC_CONST;
#define MX_TYPE_ACTOR_MANAGER_ERROR (mx_actor_manager_error_get_type())

/* enumerations from "../mx/mx-application.h" */
GType mx_application_flags_get_type (void) G_GNUC_CONST;
#define MX_TYPE_APPLICATION_FLAGS (mx_application_flags_get_type())

/* enumerations from "../mx/mx-draggable.h" */
GType mx_drag_axis_get_type (void) G_GNUC_CONST;
#define MX_TYPE_DRAG_AXIS (mx_drag_axis_get_type())

/* enumerations from "../mx/mx-focusable.h" */
GType mx_focus_direction_get_type (void) G_GNUC_CONST;
#define MX_TYPE_FOCUS_DIRECTION (mx_focus_direction_get_type())

GType mx_focus_hint_get_type (void) G_GNUC_CONST;
#define MX_TYPE_FOCUS_HINT (mx_focus_hint_get_type())

/* enumerations from "../mx/mx-image.h" */
GType mx_image_error_get_type (void) G_GNUC_CONST;
#define MX_TYPE_IMAGE_ERROR (mx_image_error_get_type())

/* enumerations from "../mx/mx-stylable.h" */
GType mx_style_changed_flags_get_type (void) G_GNUC_CONST;
#define MX_TYPE_STYLE_CHANGED_FLAGS (mx_style_changed_flags_get_type())

/* enumerations from "../mx/mx-style.h" */
GType mx_style_error_get_type (void) G_GNUC_CONST;
#define MX_TYPE_STYLE_ERROR (mx_style_error_get_type())

/* enumerations from "../mx/mx-types.h" */
GType mx_align_get_type (void) G_GNUC_CONST;
#define MX_TYPE_ALIGN (mx_align_get_type())

GType mx_font_weight_get_type (void) G_GNUC_CONST;
#define MX_TYPE_FONT_WEIGHT (mx_font_weight_get_type())

GType mx_scroll_policy_get_type (void) G_GNUC_CONST;
#define MX_TYPE_SCROLL_POLICY (mx_scroll_policy_get_type())

GType mx_orientation_get_type (void) G_GNUC_CONST;
#define MX_TYPE_ORIENTATION (mx_orientation_get_type())

GType mx_window_rotation_get_type (void) G_GNUC_CONST;
#define MX_TYPE_WINDOW_ROTATION (mx_window_rotation_get_type())

GType mx_position_get_type (void) G_GNUC_CONST;
#define MX_TYPE_POSITION (mx_position_get_type())

GType mx_image_scale_mode_get_type (void) G_GNUC_CONST;
#define MX_TYPE_IMAGE_SCALE_MODE (mx_image_scale_mode_get_type())

GType mx_tooltip_animation_get_type (void) G_GNUC_CONST;
#define MX_TYPE_TOOLTIP_ANIMATION (mx_tooltip_animation_get_type())

/* enumerations from "../mx/mx-widget.h" */
GType mx_long_press_action_get_type (void) G_GNUC_CONST;
#define MX_TYPE_LONG_PRESS_ACTION (mx_long_press_action_get_type())

G_END_DECLS

#endif /* !__MX_ENUM_TYPES_H__ */

/* Generated data ends here */
